

% Lectura del fichero generado previamente.
% Sustancia, Equivalencia TNT, Cantidad mnima de explosivo [kg], 
% Cantidad mxima de explosivo [kg], nmero de simulaciones para set.

fID = fopen('Informacion.txt');                 % Apertura del fichero.
lin=fgetl(fID);                                 % Devuelve la siguiente lnea. 
posB=find(lin==',');                            % Localiza la primera coma.
sustancia=lin(1:posB(1)-1);                     % Extrae el Nombre (termina en coma -1).
equi_TNT=str2double(lin(posB(1)+1:posB(2)-1));  % Extrae Masa equivalente.
masa_min=str2double(lin(posB(2)+1:posB(3)-1));  % Extrae Masa mnima.
masa_max=str2double(lin(posB(3)+1:posB(4)-1));  % Extrae Masa mxima.
genera_set=str2double(lin(posB(4)+1:end));      % Nmero de simulacones para el set.    

vector_masa=randi([masa_min,masa_max],1,genera_set); % Genera un conjunto aleatorio de cantidades de masa explosiva.

for i=1:length(vector_masa)
    masa_equivalente=vector_masa(i)*equi_TNT;
    % Clculo z escalada:
    distancia_p5000=exp(log(5000/(1.83*1e5))/-1.16);    % Zona de Alerta escalada (5000 Pascales).
    distancia_p12500=exp(log(12500/(1.13*1e6))/-2.01);  % Zona de Intervencin escalada (12500 Pascales).
    distancia_p16000=exp(log(16000/(1.13*1e6))/-2.01);  % Zona de Efecto Domin escalada (16000 Pascales).
    % Clculo z:
    distancia_5000(i)=distancia_p5000*(masa_equivalente^(1/3));   % Zona de Alerta (5000 Pascales). 
    distancia_12500(i)=distancia_p12500*(masa_equivalente^(1/3)); % Zona de Intervencin (12500 Pascales).
    distancia_16000(i)=distancia_p16000*(masa_equivalente^(1/3)); % Zona de Efecto Domin (16000 Pascales).
end

figure()
plot (vector_masa,distancia_5000,'x');
title 'Zona de Alerta';
xlabel 'Masa [kg]';
ylabel 'Distancia [m]';
grid on;

figure()
plot (vector_masa,distancia_12500,'x');
title 'Zona de Intervencion';
xlabel 'Masa [kg]';
ylabel 'Distancia [m]';
grid on;

figure()
plot (vector_masa,distancia_16000,'x');
title 'Zona de Efecto Domino';
xlabel 'Masa [kg]';
ylabel 'Distancia [m]';
grid on;

% Escritura del fichero con los resultados.

train=round(length(vector_masa)*0.6);                   % Diferencia entre conjunto de entrenamiento...
test=length(vector_masa)-train;                         % ... y conjunto de test.

fID=fopen('solucionesTrain.txt','wt');                  % Crea fichero de salida "Train"
formato='%5.5f %5.5f %5.5f %5.5f\n';                    % Define formato.
for i=1:train                                           % Para cada masa inserta...
    fprintf(fID,'%5.5f, ',vector_masa(i));              % ... masa, ...
    fprintf(fID,'%5.5f, ',distancia_5000(i));           % ... Zona de Alerta, ...
    fprintf(fID,'%5.5f, ',distancia_12500(i));          % ... Zona de Intervencin, ...
    fprintf(fID,'%5.5f \n',distancia_16000(i));         % ... Zona de Efecto Domin.
end
fclose(fID);

fID=fopen('solucionesTest.txt','wt');                   % Crea fichero de salida "Test"
formato='%5.5f %5.5f %5.5f %5.5f\n';                    % Define formato.
for i=train+1:train+test                                % Para cada masa inserta...
    fprintf(fID,'%5.5f, ',vector_masa(i));              % ... masa, ...
    fprintf(fID,'%5.5f, ',distancia_5000(i));           % ... Zona de Alerta, ...
    fprintf(fID,'%5.5f, ',distancia_12500(i));          % ... Zona de Intervencin, ...
    fprintf(fID,'%5.5f \n',distancia_16000(i));         % ... Zona de Efecto Domin.
end
fclose(fID);
